==> haskell-parsec-3.1.11-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-parsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parsec
version: 3.1.11
id: parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY
key: parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY
license: BSD3
maintainer: Antoine Latter <aslatter@gmail.com>
homepage: https://github.com/aslatter/parsec
synopsis: Monadic parser combinators
description:
    Parsec is designed from scratch as an industrial-strength parser
    library.  It is simple, safe, well documented (on the package
    homepage), has extensive libraries, good error messages,
    and is fast.  It is defined as a monad transformer that can be
    stacked on arbitrary monads, and it is also parametric in the
    input stream type.
category: Parsing
author: Daan Leijen <daan@microsoft.com>, Paolo Martini <paolo@nemail.it>
exposed: True
exposed-modules:
    Text.Parsec Text.Parsec.String Text.Parsec.ByteString
    Text.Parsec.ByteString.Lazy Text.Parsec.Text Text.Parsec.Text.Lazy
    Text.Parsec.Pos Text.Parsec.Error Text.Parsec.Prim Text.Parsec.Char
    Text.Parsec.Combinator Text.Parsec.Token Text.Parsec.Expr
    Text.Parsec.Language Text.Parsec.Perm Text.ParserCombinators.Parsec
    Text.ParserCombinators.Parsec.Char
    Text.ParserCombinators.Parsec.Combinator
    Text.ParserCombinators.Parsec.Error
    Text.ParserCombinators.Parsec.Expr
    Text.ParserCombinators.Parsec.Language
    Text.ParserCombinators.Parsec.Perm
    Text.ParserCombinators.Parsec.Pos
    Text.ParserCombinators.Parsec.Prim
    Text.ParserCombinators.Parsec.Token
abi: ed39ceec8095d29290f6f79b6edb31fc
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/parsec-3.1.11
library-dirs: /usr/lib/ghc-8.0.1/site-local/parsec-3.1.11
data-dir: /usr/share/i386-linux-ghc-8.0.1/parsec-3.1.11
hs-libraries: HSparsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY
depends:
    base-4.9.0.0 bytestring-0.10.8.1 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-parsec/html/parsec.haddock
haddock-html: /usr/share/doc/haskell-parsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parsec-3.1.11-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-parsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parsec
version: 3.1.11
id: parsec-3.1.11-LsiSww7OPVN4zZBDwUQHXr
key: parsec-3.1.11-LsiSww7OPVN4zZBDwUQHXr
license: BSD3
maintainer: Antoine Latter <aslatter@gmail.com>
homepage: https://github.com/aslatter/parsec
synopsis: Monadic parser combinators
description:
    Parsec is designed from scratch as an industrial-strength parser
    library.  It is simple, safe, well documented (on the package
    homepage), has extensive libraries, good error messages,
    and is fast.  It is defined as a monad transformer that can be
    stacked on arbitrary monads, and it is also parametric in the
    input stream type.
category: Parsing
author: Daan Leijen <daan@microsoft.com>, Paolo Martini <paolo@nemail.it>
exposed: True
exposed-modules:
    Text.Parsec Text.Parsec.String Text.Parsec.ByteString
    Text.Parsec.ByteString.Lazy Text.Parsec.Text Text.Parsec.Text.Lazy
    Text.Parsec.Pos Text.Parsec.Error Text.Parsec.Prim Text.Parsec.Char
    Text.Parsec.Combinator Text.Parsec.Token Text.Parsec.Expr
    Text.Parsec.Language Text.Parsec.Perm Text.ParserCombinators.Parsec
    Text.ParserCombinators.Parsec.Char
    Text.ParserCombinators.Parsec.Combinator
    Text.ParserCombinators.Parsec.Error
    Text.ParserCombinators.Parsec.Expr
    Text.ParserCombinators.Parsec.Language
    Text.ParserCombinators.Parsec.Perm
    Text.ParserCombinators.Parsec.Pos
    Text.ParserCombinators.Parsec.Prim
    Text.ParserCombinators.Parsec.Token
abi: c455a37324dd8092165b11c8dd368227
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/parsec-3.1.11
library-dirs: /usr/lib/ghc-8.0.1/site-local/parsec-3.1.11
data-dir: /usr/share/i386-linux-ghc-8.0.1/parsec-3.1.11
hs-libraries: HSparsec-3.1.11-LsiSww7OPVN4zZBDwUQHXr
depends:
    base-4.9.0.0 bytestring-0.10.8.1 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
haddock-interfaces: /usr/share/doc/haskell-parsec/html/parsec.haddock
haddock-html: /usr/share/doc/haskell-parsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
